from __future__ import unicode_literals

from django.apps import AppConfig


class ThriveMessagesConfig(AppConfig):
    name = 'hx_toolkit'
